@@ -14,12 +14,15 @@ from django.http import HttpResponseRedirect, Http404
 from django.shortcuts import render,render_to_response
 from django.template import RequestContext
 
-from oppia.models import Course, Tracker, Tag, CourseTag, Schedule, ActivitySchedule, Activity, Cohort, Participant, Points
-from oppia.forms import UploadCourseForm, ScheduleForm, ActivityScheduleForm, CohortForm
+from oppia.forms import UploadCourseForm, ScheduleForm
+from oppia.forms import ActivityScheduleForm, CohortForm
+from oppia.models import Course, Tracker, Tag, CourseTag, Schedule
+from oppia.models import ActivitySchedule, Activity, Cohort, Participant, Points
+from oppia.quiz.models import Quiz, QuizAttempt, QuizAttemptResponse
+
 from uploader import handle_uploaded_file
 
 
-  
 def home_view(request):
     activity = []
     if request.user.is_authenticated():
@@ -37,7 +40,7 @@ def home_view(request):
 
 def course_view(request):
     course_list = Course.objects.all().order_by('title')    
-    return render_to_response('oppia/course.html',{'course_list': course_list,}, context_instance=RequestContext(request))
+    return render_to_response('oppia/course/course.html',{'course_list': course_list,}, context_instance=RequestContext(request))
 
        
 def terms_view(request):
@@ -96,7 +99,7 @@ def recent_activity(request,id):
         count_media = Tracker.objects.filter(course=course,type='media',tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).exclude(user_id__in=staff).count()
         dates.append([temp.strftime("%d %b %y"),count_act_page,count_act_quiz,count_media])
     leaderboard = Points.get_leaderboard(10, course)
-    return render_to_response('oppia/course-activity.html',{'course': course,'data':dates, 'leaderboard':leaderboard}, context_instance=RequestContext(request))
+    return render_to_response('oppia/course/activity.html',{'course': course,'data':dates, 'leaderboard':leaderboard}, context_instance=RequestContext(request))
 
 def recent_activity_detail(request,id):
     course = check_owner(request,id)
@@ -114,16 +117,16 @@ def recent_activity_detail(request,id):
     try:
         tracks = paginator.page(page)
         for t in tracks:
-            t.title = t.get_activity_title()
+            t.title = t.get_activity_title()                
     except (EmptyPage, InvalidPage):
         tracks = paginator.page(paginator.num_pages)
-    return render_to_response('oppia/course-activity-detail.html',{'course': course,'page':tracks,}, context_instance=RequestContext(request))
+    return render_to_response('oppia/course/activity-detail.html',{'course': course,'page':tracks,}, context_instance=RequestContext(request))
 
 
 def schedule(request,course_id):
     course = check_owner(request,course_id)    
     schedules = Schedule.objects.filter(course=course)
-    return render_to_response('oppia/course-schedules.html',{'course': course,'schedules':schedules,}, context_instance=RequestContext(request))
+    return render_to_response('oppia/course/schedules.html',{'course': course,'schedules':schedules,}, context_instance=RequestContext(request))
     
 def schedule_add(request,course_id):
     course = check_owner(request,course_id)
@@ -252,7 +255,7 @@ def schedule_saved(request, course_id, schedule_id=None):
 def cohort(request,course_id):
     course = check_owner(request,course_id)    
     cohorts = Cohort.objects.filter(course=course)
-    return render_to_response('oppia/course-cohorts.html',{'course': course,'cohorts':cohorts,}, context_instance=RequestContext(request))
+    return render_to_response('oppia/course/cohorts.html',{'course': course,'cohorts':cohorts,}, context_instance=RequestContext(request))
   
 def cohort_add(request,course_id):
     course = check_owner(request,course_id)
@@ -378,4 +381,35 @@ def leaderboard_view(request):
     except (EmptyPage, InvalidPage):
         leaderboard = paginator.page(paginator.num_pages)
 
-    return render_to_response('oppia/leaderboard.html',{'page':leaderboard}, context_instance=RequestContext(request))
\ No newline at end of file
+    return render_to_response('oppia/leaderboard.html',{'page':leaderboard}, context_instance=RequestContext(request))
+
+def course_quiz(request,course_id):
+    course = check_owner(request,course_id)
+    digests = Activity.objects.filter(section__course=course,type='quiz').values('digest').distinct()
+    quizzes = Quiz.objects.filter(quizprops__name='digest',quizprops__value__in=digests)
+    
+    return render_to_response('oppia/course/quizzes.html',{'course': course,'quizzes':quizzes}, context_instance=RequestContext(request))
+
+def course_quiz_attempts(request,course_id,quiz_id):
+    #get the quiz digests for this course
+    course = check_owner(request,course_id)
+    quiz = Quiz.objects.get(pk=quiz_id)
+    attempts = QuizAttempt.objects.filter(quiz=quiz).order_by('-attempt_date')
+    
+    paginator = Paginator(attempts, 25)
+    # Make sure page request is an int. If not, deliver first page.
+    try:
+        page = int(request.GET.get('page', '1'))
+    except ValueError:
+        page = 1
+
+    # If page request (9999) is out of range, deliver last page of results.
+    try:
+        attempts = paginator.page(page)
+        for a in attempts:
+            a.responses = QuizAttemptResponse.objects.filter(quizattempt=a)                
+    except (EmptyPage, InvalidPage):
+        tracks = paginator.page(paginator.num_pages)
+    
+     
+    return render_to_response('oppia/course/quiz-attempts.html',{'course': course,'quiz':quiz, 'page':attempts}, context_instance=RequestContext(request))
\ No newline at end of file
